% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/AllGenerics.R, R/plotExprHeatmap.R
\docType{methods}
\name{plotExprHeatmap}
\alias{plotExprHeatmap}
\alias{plotExprHeatmap,daFrame-method}
\title{Plot expression heatmap}
\usage{
plotExprHeatmap(x, ...)

\S4method{plotExprHeatmap}{daFrame}(x, anno = TRUE, color_by = NULL,
  palette = brewer.pal(n = 8, name = "YlGnBu"), scale = TRUE,
  draw_freqs = FALSE, clustering_distance = "euclidean",
  clustering_linkage = "average")
}
\arguments{
\item{x}{a \code{\link{daFrame}}.}

\item{...}{optional arguments.}

\item{anno}{logical. Specifies whether to display values insinde each bin.}

\item{color_by}{character string. Specifies the row annotation.}

\item{palette}{character vector of colors to interpolate.}

\item{scale}{logical. Specifies whether scaled values should be displayed.
(see below for details)}

\item{draw_freqs}{logical. Specifyies whether to display cell counts and proportions.}

\item{clustering_distance}{a character string that specifies the metric to use in 
\code{\link[stats]{dist}()} for clustering.}

\item{clustering_linkage}{a character string that specifies the linkage to use in
\code{\link[stats]{hclust}()} for clustering.}
}
\value{
a \code{\link{HeatmapList-class}} object.
}
\description{
Plots median marker expressions across samples 
computed on arcsinh-transformed intensities.
}
\details{
Scaled values corresponds to cofactor arcsinh-transformed 
expression values scaled between 0 and 1 using 1% and 99% percentiles as 
boundaries. Hierarchical clustering is performed on the unscaled data.
}
\examples{
data(PBMC_fs, PBMC_panel, PBMC_md)
daf <- daFrame(PBMC_fs, PBMC_panel, PBMC_md)
plotExprHeatmap(daf[, 1:5], color_by="condition", draw_freqs=TRUE)

}
\references{
Nowicka M, Krieg C, Weber LM et al. 
CyTOF workflow: Differential discovery in 
high-throughput high-dimensional cytometry datasets.
\emph{F1000Research} 2017, 6:748 (doi: 10.12688/f1000research.11622.1)
}
\author{
Helena Lucia Crowell \email{helena.crowell@uzh.ch}
}
